/******************************************************************************/
/*                                                                            */
/*              SAS Program for TIMSS 2007 User Guide Example 3               */
/*                TIMSS 2007 International Report Exhibit 6.3                 */
/*                                                                            */
/******************************************************************************/

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <datpath> must be edited ;

LIBNAME T07 "<datpath>" ;

* Issue the include command to include the JACKGPV macro in the program ;
* <macpath> must be edited following the format x:\xxx\ ;

%INCLUDE "<macpath>JACKPV.SAS" ;

* Get and sort the teacher data ;

PROC SORT DATA = T07.BTMALLM4 OUT = BTMALLM4 ;
     BY IDCNTRY IDTEACH IDLINK ;

* Get and sort the student-teacher linkage data ;

PROC SORT DATA = T07.BSTALLM4 OUT = BSTALLM4 ;
     BY IDCNTRY IDTEACH IDLINK ;

* Merge the two files ;

DATA MERGED ;
     MERGE BTMALLM4 (IN = INBTM)
           BSTALLM4 (IN = INBST) ;
     BY IDCNTRY IDTEACH IDLINK ;
     IF INBTM AND INBST ;

* Read the merged file and select cases of interest ;

DATA MERGED ;
     SET MERGED ;

     * Select cases with no missing data ;

     IF NMISS (BT4GAGE) = 0 ;

     * Combine categories of BT4GAGE ;

     SELECT (BT4GAGE) ;
      WHEN (1,2) NEWAGE = 1 ;  * 29 YEARS OR UNDER ;
      WHEN (3)   NEWAGE = 2 ;  * 30-39 YEARS OLD ;
      WHEN (4)   NEWAGE = 3 ;  * 40-49 YEARS OLD ;
      WHEN (5,6) NEWAGE = 4 ;  * 50 YEARS OR OLDER ;
      OTHERWISE  NEWAGE = . ;
     END ;

* Define formats for the variables used ;

PROC FORMAT LIBRARY = WORK ;

 VALUE COUNTRY
   012 = 'ALGERIA'
   051 = 'ARMENIA'
   036 = 'AUSTRALIA'
   040 = 'AUSTRIA'
   048 = 'BAHRAIN'
   070 = 'BOSNIA AND HERZEGOVINA'
   072 = 'BOTSWANA'
   100 = 'BULGARIA'
   158 = 'CHINESE TAIPEI'
   170 = 'COLOMBIA'
   196 = 'CYPRUS'
   203 = 'CZECH REPUBLIC'
   208 = 'DENMARK'
   818 = 'EGYPT'
   222 = 'EL SALVADOR'
   926 = 'ENGLAND'
   268 = 'GEORGIA'
   276 = 'GERMANY'
   288 = 'GHANA'
   344 = 'HONG KONG SAR'
   348 = 'HUNGARY'
   360 = 'INDONESIA'
   364 = 'IRAN, ISLAMIC REP. OF'
   376 = 'ISRAEL'
   380 = 'ITALY'
   392 = 'JAPAN'
   400 = 'JORDAN'
   398 = 'KAZAKHSTAN'
   410 = 'KOREA, REP. OF'
   414 = 'KUWAIT'
   428 = 'LATVIA'
   422 = 'LEBANON'
   440 = 'LITHUANIA'
   458 = 'MALAYSIA'
   470 = 'MALTA'
   496 = 'MONGOLIA'
   504 = 'MOROCCO'
   528 = 'NETHERLANDS'
   554 = 'NEW ZEALAND'
   578 = 'NORWAY'
   512 = 'OMAN'
   275 = 'PALESTINIAN NAT''L AUTH.'
   634 = 'QATAR'
   642 = 'ROMANIA'
   643 = 'RUSSIAN FEDERATION'
   682 = 'SAUDI ARABIA'
   927 = 'SCOTLAND'
   891 = 'SERBIA'
   702 = 'SINGAPORE'
   703 = 'SLOVAK REPUBLIC'
   705 = 'SLOVENIA'
   752 = 'SWEDEN'
   760 = 'SYRIAN ARAB REPUBLIC'
   764 = 'THAILAND'
   788 = 'TUNISIA'
   792 = 'TURKEY'
   804 = 'UKRAINE'
   840 = 'UNITED STATES'
   887 = 'YEMEN'
  9134 = 'ALBERTA, CANADA'
  9135 = 'BRITISH COLUMBIA, CANADA'
  9132 = 'ONTARIO, CANADA'
  9133 = 'QUEBEC, CANADA'
  3724 = 'BASQUE COUNTRY, SPAIN'
  7841 = 'DUBAI, UAE'
 12500 = 'MASSACHUSETTS, US'
 12700 = 'MINNESOTA, US' ;

 VALUE AGE
     1 = '29 YEARS OR UNDER'
     2 = '30-39 YEARS OLD'
     3 = '40-49 YEARS OLD'
     4 = '50 YEARS OR OLDER' ;

* Invoke the JACKPV macro to compute the statistics ;

%JACKPV (MATWGT, JKZONE, JKREP, 75, IDCNTRY NEWAGE, BSMMAT0, 5, MERGED) ;

* Print the results ;

PROC PRINT DATA = FINAL NOOBS ;
     VAR IDCNTRY NEWAGE N MATWGT MNPV MNPV_SE PCT PCT_SE ;
     FORMAT IDCNTRY COUNTRY. NEWAGE AGE. N 6.0 MATWGT 10.0
            MNPV MNPV_SE PCT PCT_SE 6.2 ;
RUN ;
