/******************************************************************************/
/*                                                                            */
/*              SAS Program for TIMSS 2007 User Guide Example 4               */
/*                TIMSS 2007 International Report Exhibit 8.3                 */
/*                                                                            */
/******************************************************************************/

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <datpath> must be edited ;

LIBNAME T07 "<datpath>" ;

* Issue the include command to include the JACKGPV macro in the program ;
* <macpath> must be edited following the format x:\xxx\ ;

%INCLUDE "<macpath>JACKPV.SAS" ;

* Get and sort the school data ;

PROC SORT DATA = T07.BCGALLM4 OUT = BCGALLM4 ;
     BY IDCNTRY IDSCHOOL ;

* Get and sort the student data ;

PROC SORT DATA = T07.BSGALLM4 OUT = BSGALLM4 ;
     BY IDCNTRY IDSCHOOL ;

* Merge the two files ;

DATA MERGED ;
     MERGE BCGALLM4 (IN = INBCG)
           BSGALLM4 (IN = INBSG) ;
     BY IDCNTRY IDSCHOOL ;
     IF INBCG AND INBSG ;

* Read the merged file and select cases of interest ;

DATA MERGED ;
     SET MERGED ;

     * Select cases with no missing data ;

     IF NMISS (BCDGAS) = 0 ;

* Define formats for the variables used ;

PROC FORMAT LIBRARY = WORK ;

 VALUE COUNTRY
   012 = 'ALGERIA'
   051 = 'ARMENIA'
   036 = 'AUSTRALIA'
   040 = 'AUSTRIA'
   048 = 'BAHRAIN'
   070 = 'BOSNIA AND HERZEGOVINA'
   072 = 'BOTSWANA'
   100 = 'BULGARIA'
   158 = 'CHINESE TAIPEI'
   170 = 'COLOMBIA'
   196 = 'CYPRUS'
   203 = 'CZECH REPUBLIC'
   208 = 'DENMARK'
   818 = 'EGYPT'
   222 = 'EL SALVADOR'
   926 = 'ENGLAND'
   268 = 'GEORGIA'
   276 = 'GERMANY'
   288 = 'GHANA'
   344 = 'HONG KONG SAR'
   348 = 'HUNGARY'
   360 = 'INDONESIA'
   364 = 'IRAN, ISLAMIC REP. OF'
   376 = 'ISRAEL'
   380 = 'ITALY'
   392 = 'JAPAN'
   400 = 'JORDAN'
   398 = 'KAZAKHSTAN'
   410 = 'KOREA, REP. OF'
   414 = 'KUWAIT'
   428 = 'LATVIA'
   422 = 'LEBANON'
   440 = 'LITHUANIA'
   458 = 'MALAYSIA'
   470 = 'MALTA'
   496 = 'MONGOLIA'
   504 = 'MOROCCO'
   528 = 'NETHERLANDS'
   554 = 'NEW ZEALAND'
   578 = 'NORWAY'
   512 = 'OMAN'
   275 = 'PALESTINIAN NAT''L AUTH.'
   634 = 'QATAR'
   642 = 'ROMANIA'
   643 = 'RUSSIAN FEDERATION'
   682 = 'SAUDI ARABIA'
   927 = 'SCOTLAND'
   891 = 'SERBIA'
   702 = 'SINGAPORE'
   703 = 'SLOVAK REPUBLIC'
   705 = 'SLOVENIA'
   752 = 'SWEDEN'
   760 = 'SYRIAN ARAB REPUBLIC'
   764 = 'THAILAND'
   788 = 'TUNISIA'
   792 = 'TURKEY'
   804 = 'UKRAINE'
   840 = 'UNITED STATES'
   887 = 'YEMEN'
  9134 = 'ALBERTA, CANADA'
  9135 = 'BRITISH COLUMBIA, CANADA'
  9132 = 'ONTARIO, CANADA'
  9133 = 'QUEBEC, CANADA'
  3724 = 'BASQUE COUNTRY, SPAIN'
  7841 = 'DUBAI, UAE'
 12500 = 'MASSACHUSETTS, US'
 12700 = 'MINNESOTA, US' ;

 VALUE GAS
     1 = 'HIGH'
     2 = 'MEDIUM'
     3 = 'LOW' ;

* Invoke the JACKPV macro to compute the statistics ;

%JACKPV (TOTWGT, JKZONE, JKREP, 75, IDCNTRY BCDGAS, BSMMAT0, 5, MERGED) ;

* Print the results ;

PROC PRINT DATA = FINAL NOOBS ;
     VAR IDCNTRY BCDGAS N TOTWGT MNPV MNPV_SE PCT PCT_SE ;
     FORMAT IDCNTRY COUNTRY. BCDGAS GAS. N 6.0 TOTWGT 10.0
            MNPV MNPV_SE PCT PCT_SE 6.2 ;
RUN ;
