/******************************************************************************/
/*                                                                            */
/*               Sample SAS Program to Invoke the JACKREG Macro               */
/*                           TIMSS 2007  User Guide                           */
/*                                                                            */
/******************************************************************************/

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <datpath> must be edited ;

LIBNAME T07 "<datpath>" ;

* Issue the include command to include the jackreg macro in the program ;
* <macpath> must be edited following the format x:\xxx\ ;

%INCLUDE "<macpath>JACKREG.SAS" ;

* Get the student data and select cases of interest ;

DATA BSGALLM4 ;
     SET T07.BSGALLM4 ;

     * Select cases with no missing data ;

     WHERE NMISS (ITSEX, BS4GBOOK) = 0 ;

     * Dummy recode of ITSEX ;

     SELECT (ITSEX) ;
      WHEN (1)  REGSEX = 0 ;  * GIRLS ;
      WHEN (2)  REGSEX = 1 ;  * BOYS ;
      OTHERWISE REGSEX = . ;
     END ;

     * Assign midpoints to ASBGBOOK ;

     SELECT (BS4GBOOK) ;
      WHEN (1)  BOOK =   5 ;  *   5 Books at home ;
      WHEN (2)  BOOK =  18 ;  *  18 Books at home ;
      WHEN (3)  BOOK =  63 ;  *  63 Books at home ;
      WHEN (4)  BOOK = 151 ;  * 151 Books at home ;
      WHEN (5)  BOOK = 251 ;  * 251 Books at home ;
      OTHERWISE BOOK =   . ;
     END ;

* Define formats for the variables used ;

PROC FORMAT LIBRARY = WORK ;

 VALUE COUNTRY
   012 = 'ALGERIA'
   051 = 'ARMENIA'
   036 = 'AUSTRALIA'
   040 = 'AUSTRIA'
   048 = 'BAHRAIN'
   070 = 'BOSNIA AND HERZEGOVINA'
   072 = 'BOTSWANA'
   100 = 'BULGARIA'
   158 = 'CHINESE TAIPEI'
   170 = 'COLOMBIA'
   196 = 'CYPRUS'
   203 = 'CZECH REPUBLIC'
   208 = 'DENMARK'
   818 = 'EGYPT'
   222 = 'EL SALVADOR'
   926 = 'ENGLAND'
   268 = 'GEORGIA'
   276 = 'GERMANY'
   288 = 'GHANA'
   344 = 'HONG KONG SAR'
   348 = 'HUNGARY'
   360 = 'INDONESIA'
   364 = 'IRAN, ISLAMIC REP. OF'
   376 = 'ISRAEL'
   380 = 'ITALY'
   392 = 'JAPAN'
   400 = 'JORDAN'
   398 = 'KAZAKHSTAN'
   410 = 'KOREA, REP. OF'
   414 = 'KUWAIT'
   428 = 'LATVIA'
   422 = 'LEBANON'
   440 = 'LITHUANIA'
   458 = 'MALAYSIA'
   470 = 'MALTA'
   496 = 'MONGOLIA'
   504 = 'MOROCCO'
   528 = 'NETHERLANDS'
   554 = 'NEW ZEALAND'
   578 = 'NORWAY'
   512 = 'OMAN'
   275 = 'PALESTINIAN NAT''L AUTH.'
   634 = 'QATAR'
   642 = 'ROMANIA'
   643 = 'RUSSIAN FEDERATION'
   682 = 'SAUDI ARABIA'
   927 = 'SCOTLAND'
   891 = 'SERBIA'
   702 = 'SINGAPORE'
   703 = 'SLOVAK REPUBLIC'
   705 = 'SLOVENIA'
   752 = 'SWEDEN'
   760 = 'SYRIAN ARAB REPUBLIC'
   764 = 'THAILAND'
   788 = 'TUNISIA'
   792 = 'TURKEY'
   804 = 'UKRAINE'
   840 = 'UNITED STATES'
   887 = 'YEMEN'
  9134 = 'ALBERTA, CANADA'
  9135 = 'BRITISH COLUMBIA, CANADA'
  9132 = 'ONTARIO, CANADA'
  9133 = 'QUEBEC, CANADA'
  3724 = 'BASQUE COUNTRY, SPAIN'
  7841 = 'DUBAI, UAE'
 12500 = 'MASSACHUSETTS, US'
 12700 = 'MINNESOTA, US' ;

* Invoke the JACKREG macro to compute the statistics ;

%JACKREG (TOTWGT, JKZONE, JKREP, 75, IDCNTRY, REGSEX, BOOK, BSGALLM4) ;

* Print the results ;

PROC PRINT DATA = REG NOOBS ;
     VAR IDCNTRY N MULT_RSQ SS_TOTAL SS_REG B00 B00_SE B01 B01_SE ;
     FORMAT IDCNTRY COUNTRY. N 6.0 MULT_RSQ 5.3 SS_TOTAL SS_REG 10.0
            B00 B00_SE B01 B01_SE 6.2 ;
RUN ;
